@@ -2,6 +2,9 @@
  * Copyright (C) 2009, Pino Toscano <pino@kde.org>
  * Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
  * Copyright (C) 2014, Hans-Peter Deifel <hpdeifel@gmx.de>
+ * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
+ * Copyright (C) 2018, Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
+ * Copyright (C) 2018, Adam Reichold <adam.reichold@t-online.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,8 +53,6 @@ ustring unicode_GooString_to_ustring(GooString *str);
 ustring unicode_to_ustring(const Unicode *u, int length);
 GooString* ustring_to_unicode_GooString(const ustring &str);
 
-time_type convert_date(const char *date);
-
 }
 
 template <typename ConstIterator>
@@ -68,6 +69,16 @@ void delete_all(const Collection &c)
     delete_all(c.begin(), c.end());
 }
 
+struct text_box_data
+{
+    ~text_box_data();
+
+    ustring text;
+    rectf bbox;
+    std::vector<rectf> char_bboxes;
+    bool has_space_after;
+};
+
 }
 
 #endif
