@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009, Pino Toscano <pino@kde.org>
+ * Copyright (C) 2018, Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +50,9 @@ public:
     toc_item_private();
     ~toc_item_private();
 
+    toc_item_private(const toc_item_private &) = delete;
+    toc_item_private& operator=(const toc_item_private &) = delete;
+
     void load(OutlineItem *item);
     void load_children(GooList *items);
 
