@@ -167,7 +167,7 @@ _poppler_create_annot (GType annot_type, Annot *annot)
 {
   PopplerAnnot *poppler_annot;
 
-  poppler_annot = POPPLER_ANNOT (g_object_new (annot_type, NULL));
+  poppler_annot = POPPLER_ANNOT (g_object_new (annot_type, nullptr));
   poppler_annot->annot = annot;
   annot->incRefCnt();
 
@@ -181,7 +181,7 @@ poppler_annot_finalize (GObject *object)
 
   if (poppler_annot->annot) {
     poppler_annot->annot->decRefCnt();
-    poppler_annot->annot = NULL;
+    poppler_annot->annot = nullptr;
   }
 
   G_OBJECT_CLASS (poppler_annot_parent_class)->finalize (object);
@@ -382,7 +382,7 @@ poppler_annot_text_markup_new_squiggly (PopplerDocument  *doc,
   PDFRectangle pdf_rect(rect->x1, rect->y1,
 			rect->x2, rect->y2);
 
-  g_return_val_if_fail (quadrilaterals != NULL && quadrilaterals->len > 0, NULL);
+  g_return_val_if_fail (quadrilaterals != nullptr && quadrilaterals->len > 0, NULL);
 
   annot = new AnnotTextMarkup (doc->doc, &pdf_rect, Annot::typeSquiggly);
 
@@ -416,7 +416,7 @@ poppler_annot_text_markup_new_strikeout (PopplerDocument  *doc,
   PDFRectangle pdf_rect(rect->x1, rect->y1,
 			rect->x2, rect->y2);
 
-  g_return_val_if_fail (quadrilaterals != NULL && quadrilaterals->len > 0, NULL);
+  g_return_val_if_fail (quadrilaterals != nullptr && quadrilaterals->len > 0, NULL);
 
   annot = new AnnotTextMarkup (doc->doc, &pdf_rect, Annot::typeStrikeOut);
 
@@ -450,7 +450,7 @@ poppler_annot_text_markup_new_underline (PopplerDocument  *doc,
   PDFRectangle pdf_rect(rect->x1, rect->y1,
 			rect->x2, rect->y2);
 
-  g_return_val_if_fail (quadrilaterals != NULL && quadrilaterals->len > 0, NULL);
+  g_return_val_if_fail (quadrilaterals != nullptr && quadrilaterals->len > 0, NULL);
 
   annot = new AnnotTextMarkup (doc->doc, &pdf_rect, Annot::typeUnderline);
 
@@ -500,7 +500,7 @@ poppler_annot_movie_finalize (GObject *object)
 
   if (annot_movie->movie) {
     g_object_unref (annot_movie->movie);
-    annot_movie->movie = NULL;
+    annot_movie->movie = nullptr;
   }
 
   G_OBJECT_CLASS (poppler_annot_movie_parent_class)->finalize (object);
@@ -539,7 +539,7 @@ poppler_annot_screen_finalize (GObject *object)
 
   if (annot_screen->action) {
     poppler_action_free (annot_screen->action);
-    annot_screen->action = NULL;
+    annot_screen->action = nullptr;
   }
 
   G_OBJECT_CLASS (poppler_annot_screen_parent_class)->finalize (object);
@@ -559,7 +559,7 @@ poppler_annot_screen_class_init (PopplerAnnotScreenClass *klass)
 }
 
 PopplerAnnot *
-_poppler_annot_screen_new (Annot *annot)
+_poppler_annot_screen_new (PopplerDocument *doc, Annot *annot)
 {
   PopplerAnnot *poppler_annot;
   AnnotScreen  *annot_screen;
@@ -569,7 +569,7 @@ _poppler_annot_screen_new (Annot *annot)
   annot_screen = static_cast<AnnotScreen *>(poppler_annot->annot);
   action = annot_screen->getAction();
   if (action)
-    POPPLER_ANNOT_SCREEN (poppler_annot)->action = _poppler_action_new (NULL, action, NULL);
+    POPPLER_ANNOT_SCREEN (poppler_annot)->action = _poppler_action_new (doc, action, nullptr);
 
   return poppler_annot;
 }
@@ -799,7 +799,7 @@ poppler_annot_get_contents (PopplerAnnot *poppler_annot)
 
   contents = poppler_annot->annot->getContents ();
 
-  return contents ? _poppler_goo_string_to_utf8 (contents) : NULL;
+  return contents && contents->getLength() > 0 ? _poppler_goo_string_to_utf8 (contents) : nullptr;
 }
 
 /**
@@ -822,7 +822,7 @@ poppler_annot_set_contents (PopplerAnnot *poppler_annot,
   
   g_return_if_fail (POPPLER_IS_ANNOT (poppler_annot));
 
-  tmp = contents ? g_convert (contents, -1, "UTF-16BE", "UTF-8", NULL, &length, NULL) : NULL;
+  tmp = contents ? g_convert (contents, -1, "UTF-16BE", "UTF-8", nullptr, &length, nullptr) : nullptr;
   goo_tmp = new GooString (tmp, length);
   g_free (tmp);
   poppler_annot->annot->setContents (goo_tmp);
@@ -847,7 +847,7 @@ poppler_annot_get_name (PopplerAnnot *poppler_annot)
 
   name = poppler_annot->annot->getName ();
 
-  return name ? _poppler_goo_string_to_utf8 (name) : NULL;
+  return name ? _poppler_goo_string_to_utf8 (name) : nullptr;
 }
 
 /**
@@ -870,7 +870,7 @@ poppler_annot_get_modified (PopplerAnnot *poppler_annot)
 
   text = poppler_annot->annot->getModified ();
 
-  return text ? _poppler_goo_string_to_utf8 (text) : NULL;
+  return text ? _poppler_goo_string_to_utf8 (text) : nullptr;
 }
 
 /**
@@ -914,7 +914,7 @@ poppler_annot_set_flags (PopplerAnnot *poppler_annot, PopplerAnnotFlag flags)
 static PopplerColor *
 create_poppler_color_from_annot_color (AnnotColor *color)
 {
-  PopplerColor *poppler_color = NULL;
+  PopplerColor *poppler_color = nullptr;
 
   if (color) {
     const double *values = color->getValues ();
@@ -951,7 +951,7 @@ static AnnotColor *
 create_annot_color_from_poppler_color (PopplerColor *poppler_color)
 {
   if (!poppler_color)
-    return NULL;
+    return nullptr;
 
   return new AnnotColor ((double)poppler_color->red / 65535,
                          (double)poppler_color->green / 65535,
@@ -1030,7 +1030,7 @@ poppler_annot_get_rectangle (PopplerAnnot     *poppler_annot,
   PDFRectangle *annot_rect;
 
   g_return_if_fail (POPPLER_IS_ANNOT (poppler_annot));
-  g_return_if_fail (poppler_rect != NULL);
+  g_return_if_fail (poppler_rect != nullptr);
 
   annot_rect = poppler_annot->annot->getRect ();
   poppler_rect->x1 = annot_rect->x1;
@@ -1054,7 +1054,7 @@ poppler_annot_set_rectangle (PopplerAnnot     *poppler_annot,
                              PopplerRectangle *poppler_rect)
 {
   g_return_if_fail (POPPLER_IS_ANNOT (poppler_annot));
-  g_return_if_fail (poppler_rect != NULL);
+  g_return_if_fail (poppler_rect != nullptr);
 
   poppler_annot->annot->setRect (poppler_rect->x1, poppler_rect->y1,
                                  poppler_rect->x2, poppler_rect->y2);
@@ -1081,7 +1081,7 @@ poppler_annot_markup_get_label (PopplerAnnotMarkup *poppler_annot)
 
   text = annot->getLabel ();
 
-  return text ? _poppler_goo_string_to_utf8 (text) : NULL;
+  return text ? _poppler_goo_string_to_utf8 (text) : nullptr;
 }
 
 /**
@@ -1106,7 +1106,7 @@ poppler_annot_markup_set_label (PopplerAnnotMarkup *poppler_annot,
 
   annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT (poppler_annot)->annot);
 
-  tmp = label ? g_convert (label, -1, "UTF-16BE", "UTF-8", NULL, &length, NULL) : NULL;
+  tmp = label ? g_convert (label, -1, "UTF-16BE", "UTF-8", nullptr, &length, nullptr) : nullptr;
   goo_tmp = new GooString (tmp, length);
   g_free (tmp);
   annot->setLabel (goo_tmp);
@@ -1132,7 +1132,7 @@ poppler_annot_markup_has_popup (PopplerAnnotMarkup *poppler_annot)
 
   annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT (poppler_annot)->annot);
 
-  return annot->getPopup () != NULL;
+  return annot->getPopup () != nullptr;
 }
 
 /**
@@ -1234,7 +1234,7 @@ poppler_annot_markup_get_popup_rectangle (PopplerAnnotMarkup *poppler_annot,
   PDFRectangle *annot_rect;
 
   g_return_val_if_fail (POPPLER_IS_ANNOT_MARKUP (poppler_annot), FALSE);
-  g_return_val_if_fail (poppler_rect != NULL, FALSE);
+  g_return_val_if_fail (poppler_rect != nullptr, FALSE);
 
   annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT (poppler_annot)->annot);
   annot_popup = annot->getPopup ();
@@ -1250,6 +1250,37 @@ poppler_annot_markup_get_popup_rectangle (PopplerAnnotMarkup *poppler_annot,
   return TRUE;
 }
 
+/**
+ * poppler_annot_markup_set_popup_rectangle:
+ * @poppler_annot: a #PopplerAnnotMarkup
+ * @poppler_rect: a #PopplerRectangle to set
+ *
+ * Sets the rectangle of the popup window related to @poppler_annot.
+ * This doesn't have any effect if @poppler_annot doesn't have a
+ * popup associated, use poppler_annot_markup_set_popup() to associate
+ * a popup window to a #PopplerAnnotMarkup.
+ *
+ * Since: 0.33
+ */
+void
+poppler_annot_markup_set_popup_rectangle (PopplerAnnotMarkup *poppler_annot,
+                                          PopplerRectangle   *poppler_rect)
+{
+        AnnotMarkup *annot;
+        Annot *annot_popup;
+
+        g_return_if_fail (POPPLER_IS_ANNOT_MARKUP (poppler_annot));
+        g_return_if_fail (poppler_rect != nullptr);
+
+        annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT (poppler_annot)->annot);
+        annot_popup = annot->getPopup ();
+        if (!annot_popup)
+                return;
+
+        annot_popup->setRect (poppler_rect->x1, poppler_rect->y1,
+                              poppler_rect->x2, poppler_rect->y2);
+}
+
 /**
  * poppler_annot_markup_get_opacity:
  * @poppler_annot: a #PopplerAnnotMarkup
@@ -1315,7 +1346,7 @@ poppler_annot_markup_get_date (PopplerAnnotMarkup *poppler_annot)
   annot = static_cast<AnnotMarkup *>(POPPLER_ANNOT (poppler_annot)->annot);
   annot_date = annot->getDate ();
   if (!annot_date)
-    return NULL;
+    return nullptr;
 
   if (_poppler_convert_pdf_date_to_gtime (annot_date, &timet)) {
     GDate *date;
@@ -1326,7 +1357,7 @@ poppler_annot_markup_get_date (PopplerAnnotMarkup *poppler_annot)
     return date;
   }
 
-  return NULL;
+  return nullptr;
 }
 
 /**
@@ -1349,7 +1380,7 @@ poppler_annot_markup_get_subject (PopplerAnnotMarkup *poppler_annot)
 
   text = annot->getSubject ();
 
-  return text ? _poppler_goo_string_to_utf8 (text) : NULL;
+  return text ? _poppler_goo_string_to_utf8 (text) : nullptr;
 }
 
 /**
@@ -1475,7 +1506,7 @@ poppler_annot_text_get_icon (PopplerAnnotText *poppler_annot)
 
   text = annot->getIcon ();
 
-  return text ? _poppler_goo_string_to_utf8 (text) : NULL;
+  return text ? _poppler_goo_string_to_utf8 (text) : nullptr;
 }
 
 /**
@@ -1593,7 +1624,7 @@ poppler_annot_text_markup_set_quadrilaterals (PopplerAnnotTextMarkup *poppler_an
   AnnotTextMarkup *annot;
 
   g_return_if_fail (POPPLER_IS_ANNOT_TEXT_MARKUP (poppler_annot));
-  g_return_if_fail (quadrilaterals != NULL && quadrilaterals->len > 0);
+  g_return_if_fail (quadrilaterals != nullptr && quadrilaterals->len > 0);
 
   annot = static_cast<AnnotTextMarkup *>(POPPLER_ANNOT (poppler_annot)->annot);
   AnnotQuadrilaterals *quads = create_annot_quads_from_poppler_quads (quadrilaterals);
@@ -1699,7 +1730,7 @@ poppler_annot_free_text_get_callout_line (PopplerAnnotFreeText *poppler_annot)
     return callout;
   }
 
-  return NULL;
+  return nullptr;
 }
 
 /* PopplerAnnotFileAttachment */
@@ -1752,7 +1783,7 @@ poppler_annot_file_attachment_get_name (PopplerAnnotFileAttachment *poppler_anno
   annot = static_cast<AnnotFileAttachment *>(POPPLER_ANNOT (poppler_annot)->annot);
   name = annot->getName ();
 
-  return name ? _poppler_goo_string_to_utf8 (name) : NULL;
+  return name ? _poppler_goo_string_to_utf8 (name) : nullptr;
 }
 
 /* PopplerAnnotCalloutLine */
@@ -1788,7 +1819,7 @@ poppler_annot_callout_line_copy (PopplerAnnotCalloutLine *callout)
 {
   PopplerAnnotCalloutLine *new_callout;
 
-  g_return_val_if_fail (callout != NULL, NULL);
+  g_return_val_if_fail (callout != nullptr, NULL);
   
   new_callout = g_new0 (PopplerAnnotCalloutLine, 1);
   *new_callout = *callout;
@@ -1832,7 +1863,7 @@ poppler_annot_movie_get_title (PopplerAnnotMovie *poppler_annot)
 
   title = annot->getTitle ();
 
-  return title ? _poppler_goo_string_to_utf8 (title) : NULL;
+  return title ? _poppler_goo_string_to_utf8 (title) : nullptr;
 }
 
 /**
@@ -1889,8 +1920,8 @@ poppler_annot_line_set_vertices (PopplerAnnotLine *poppler_annot,
   AnnotLine *annot;
 
   g_return_if_fail (POPPLER_IS_ANNOT_LINE (poppler_annot));
-  g_return_if_fail (start != NULL);
-  g_return_if_fail (end != NULL);
+  g_return_if_fail (start != nullptr);
+  g_return_if_fail (end != nullptr);
 
   annot = static_cast<AnnotLine *>(POPPLER_ANNOT (poppler_annot)->annot);
   annot->setVertices (start->x, start->y, end->x, end->y);
