@@ -1,7 +1,7 @@
 /* poppler-private.h: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, 2008, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2006-2009, 2011, 2012 by Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2006-2009, 2011, 2012, 2017, 2018 by Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2007-2009, 2011, 2014 by Pino Toscano <pino@kde.org>
  * Copyright (C) 2011 Andreas Hartmetz <ahartmetz@gmail.com>
  * Copyright (C) 2011 Hib Eris <hib@hiberis.nl>
@@ -103,10 +103,8 @@ namespace Poppler {
 	
 	DocumentData(const QByteArray &data, GooString *ownerPassword, GooString *userPassword)
 	    {
-		Object obj;
 		fileContents = data;
-		obj.initNull();
-		MemStream *str = new MemStream((char*)fileContents.data(), 0, fileContents.length(), &obj);
+		MemStream *str = new MemStream((char*)fileContents.data(), 0, fileContents.length(), Object(objNull));
 		init();
 		doc = new PDFDoc(str, ownerPassword, userPassword);
 		delete ownerPassword;
@@ -116,6 +114,9 @@ namespace Poppler {
 	void init();
 	
 	~DocumentData();
+
+	DocumentData(const DocumentData &) = delete;
+	DocumentData& operator=(const DocumentData &) = delete;
 	
 	void addTocChildren( QDomDocument * docSyn, QDomNode * parent, GooList * items );
 	
@@ -160,16 +161,6 @@ namespace Poppler {
 			type = FontInfo::unknown;
 		}
 		
-		FontInfoData( const FontInfoData &fid )
-		{
-			fontName = fid.fontName;
-			fontFile = fid.fontFile;
-			isEmbedded = fid.isEmbedded;
-			isSubset = fid.isSubset;
-			type = fid.type;
-			embRef = fid.embRef;
-		}
-		
 		FontInfoData( ::FontInfo* fi )
 		{
 			if (fi->getName()) fontName = fi->getName()->getCString();
@@ -180,6 +171,9 @@ namespace Poppler {
 			embRef = fi->getEmbRef();
 		}
 
+		FontInfoData( const FontInfoData &fid ) = default;
+		FontInfoData& operator=(const FontInfoData &) = default;
+
 		QString fontName;
 		QString fontFile;
 		bool isEmbedded : 1;
@@ -211,7 +205,7 @@ namespace Poppler {
     {
 	public:
 		TextBoxData()
-		  : nextWord(0), hasSpaceAfter(false)
+		  : nextWord(nullptr), hasSpaceAfter(false)
 		{
 		}
 
